@@ -21,7 +21,7 @@ from network.base.forms import ObservationFormSet, SatelliteFilterForm
 from network.base.models import Observation, Satellite, Station
 from network.base.perms import schedule_perms, schedule_station_violators_perms
 from network.base.scheduling import create_new_observation, get_available_stations, \
-    predict_available_observation_windows
+    over_min_duration, predict_available_observation_windows
 from network.base.serializers import StationSerializer
 from network.base.stats import satellite_stats_by_transmitter_list, transmitters_with_stats
 from network.base.validators import NegativeElevationError, NoTleSetError, \
@@ -145,56 +145,81 @@ def observation_new(request):
             'date_min_start': settings.OBSERVATION_DATE_MIN_START,
             'date_min_end': settings.OBSERVATION_DATE_MIN_END,
             'date_max_range': settings.OBSERVATION_DATE_MAX_RANGE,
-            'warn_min_obs': settings.OBSERVATION_WARN_MIN_OBS
+            'warn_min_obs': settings.OBSERVATION_WARN_MIN_OBS,
+            'obs_min_duration': settings.OBSERVATION_DURATION_MIN,
+            'split': {
+                'duration': settings.OBSERVATION_SPLIT_DURATION,
+                'break': settings.OBSERVATION_SPLIT_BREAK_DURATION
+            }
         }
     )
 
 
 def prediction_windows_parse_parameters(request):
     """ Parse HTTP parameters with defaults"""
-    return {
+    params = {
         'sat_norad_id': request.POST['satellite'],
         'transmitter': request.POST['transmitter'],
         'start': make_aware(datetime.strptime(request.POST['start'], '%Y-%m-%d %H:%M'), utc),
         'end': make_aware(datetime.strptime(request.POST['end'], '%Y-%m-%d %H:%M'), utc),
         'station_ids': request.POST.getlist('stations[]', []),
         'min_horizon': request.POST.get('min_horizon', None),
+        'split_duration': int(
+            request.POST.get('split_duration', settings.OBSERVATION_SPLIT_DURATION)
+        ),
+        'break_duration': int(
+            request.POST.get('break_duration', settings.OBSERVATION_SPLIT_BREAK_DURATION)
+        ),
         'overlapped': int(request.POST.get('overlapped', 0)),
     }
 
+    if params['split_duration'] < 0 or params['break_duration'] < 0:
+        raise ValueError('Please re-check your request parameters.')
+    if not over_min_duration(params['split_duration']):
+        raise ValueError(
+            'Split duration should be over minimum observation duration({} seconds)'.format(
+                settings.OBSERVATION_DURATION_MIN
+            )
+        )
+
+    return params
+
 
 @ajax_required
 def prediction_windows(request):
     """Calculates and returns passes of satellites over stations"""
 
-    params = prediction_windows_parse_parameters(request)
-
-    # Check the selected satellite exists and is alive
     try:
+        error_found = True
+        # Parse parameters and validate parameters
+        params = prediction_windows_parse_parameters(request)
+
+        # Check the selected satellite exists and is alive
         satellite = Satellite.objects.filter(status='alive'
                                              ).get(norad_cat_id=params['sat_norad_id'])
-    except Satellite.DoesNotExist:
-        data = [{'error': 'You should select a Satellite first.'}]
-        return JsonResponse(data, safe=False)
 
-    try:
         # Check if there is a TLE available for this satellite
         tle_set = get_tle_set_by_norad_id(satellite.norad_cat_id)
         if tle_set:
             tle = tle_set[0]
         else:
-            data = [{'error': 'No TLEs for this satellite yet.'}]
-            return JsonResponse(data, safe=False)
+            raise ValueError('No TLEs for this satellite yet.')
 
         # Check the selected transmitter exists, and if yes,
         # store this transmitter in the downlink variable
         transmitter = get_transmitter_by_uuid(params['transmitter'])
         if not transmitter:
-            data = [{'error': 'You should select a valid Transmitter.'}]
-            return JsonResponse(data, safe=False)
+            raise ValueError('You should select a valid Transmitter.')
         downlink = transmitter[0]['downlink_low']
+        error_found = False
+    except ValueError as error:
+        data = [{'error': str(error)}]
+    except Satellite.DoesNotExist:
+        data = [{'error': 'You should select a Satellite first.'}]
     except DBConnectionError as error:
         data = [{'error': str(error)}]
+
+    if error_found:
         return JsonResponse(data, safe=False)
 
     # Fetch all available ground stations
@@ -239,7 +264,10 @@ def prediction_windows(request):
     for station in available_stations:
         station_passes, station_windows = predict_available_observation_windows(
             station, params['min_horizon'], params['overlapped'], tle, params['start'],
-            params['end']
+            params['end'], {
+                'split': params['split_duration'],
+                'break': params['break_duration']
+            }
         )
         passes_found[station.id] = station_passes
         if station_windows:
@@ -328,7 +356,10 @@ def pass_predictions(request, station_id):
                 continue
 
             _, station_windows = predict_available_observation_windows(
-                station, None, 2, tle, start, end
+                station, None, 2, tle, start, end, {
+                    'split': settings.OBSERVATION_SPLIT_DURATION,
+                    'break': settings.OBSERVATION_SPLIT_BREAK_DURATION
+                }
             )
 
             if station_windows:
