@@ -6,6 +6,14 @@ $(document).ready(function() {
     $('#antennas-loading').toggle();
     $('.selectpicker').selectpicker();
 
+    $('.panel-body.collapse').on('hide.bs.collapse', function () {
+        $(this).parent().find('.panel-heading span').addClass('glyphicon-collapse-down').removeClass('glyphicon-collapse-up');
+    });
+
+    $('.panel-body.collapse').on('show.bs.collapse', function () {
+        $(this).parent().find('.panel-heading span').addClass('glyphicon-collapse-up').removeClass('glyphicon-collapse-down');
+    });
+
     // Parse and initialize station data and remove html elements that holding them
     var station_element = $('#station-data-to-parse');
     var station_data = station_element.data();
@@ -454,6 +462,12 @@ $(document).ready(function() {
         send_remove_file = image_exists;
     });
 
+    $('#violator_scheduling').change(function(){
+        $('.violator-scheduling-option-description').hide();
+        $('#violator-scheduling-'+ this.value).show();
+    });
+    $('#violator_scheduling').change();
+
     // Submit or Cancel form
     $('#cancel').on('click', function(){
         if(this.textContent == 'Back to Dashboard'){
@@ -463,6 +477,11 @@ $(document).ready(function() {
         }
     });
 
+    $('#satnogs-rx-samp-rate').on('change', function(){
+        this.value = Number(this.value);
+    });
+    
+
     $('form').on('submit', function(){
         $('#antenna-type').remove();
         let antennas_total = 0;
